*** This do file creates market experience variables MarketExper1, MarketExper2, 
*** MarketExpos1, MarketExpos2  


capture erase "ExperVars1.dta" 	// delete the experience variables data if it exists



********* *********		MARKET EXPERIENCE 	*********	*********	



*** MarketExper1: number of times the firm has already invested in solar.
*
* For info on this command see https://www.youtube.com/watch?v=MCEU5kEUWhE 
by firmid year, sort: gen MarketExper1 = _N
sort firmid year
replace MarketExper1 = MarketExper1[_n-1] + (year != year[_n-1])*(MarketExper1) if firmid == firmid[_n-1]
****************************************************************************


*** MarketExper2: number of countries the firm has already invested in solar.
*
*Count number of host countries each firm has done in each year
by firmid year ccode2, sort: gen counteachcountryonce = (_n == 1)
*But DON'T count the country again if it's been invested in in multiple years
by firmid ccode2, sort: egen firstinv = min(year)
*don't count the country if it's not the first year this company has invested in it
replace counteachcountryonce = 0 if firstinv != year
by firmid year, sort: egen MarketExper2 = sum(counteachcountryonce)
drop counteachcountryonce firstinv
*
sort firmid year
replace MarketExper2 = MarketExper2[_n-1] + (year != year[_n-1])*(MarketExper2) if firmid == firmid[_n-1]
*
****************************************************************************



*** MarketExpos1: number of years the firm has been in solar energy (abroad).
*
by firmid , sort: egen firstyear = min(year)
*
gen MarketExpos1=year-firstyear
drop firstyear
*
****************************************************************************



*** MarketExpos2: number of years the firm has accumulated in solar energy (abroad) across all its investments.
*
*
*Fill in all data to the end of the years
summ year
local maxyear = r(max)
*For each investment, figure out how much of a gap there is from here to the end of the data.
*Add 1 to show how many copies we want to end up with (including the original)
gen gap = `maxyear' - year + 1
*Make copies.
expand gap if gap > 1, gen(newobs)
*Fill in with correct year
sort invid year newobs
replace year = year[_n-1] + 1 if invid == invid[_n-1] & newobs == 1
*
*First year invested in each country
by firmid ccode2, sort: egen firstyear = min(year)
*Replace this line with gen years_exposed = year - firstyear + 1 if you want to count the first year they're there.
gen years_exposed = year - firstyear 
by firmid year ccode2, sort: gen counteachcountryonce = (_n == 1)
*Count the number of years of experience GAINED this year
by firmid year, sort: egen gainedthisyear = sum(counteachcountryonce)
gen MarketExpos2 = gainedthisyear
*
sort firmid year
replace MarketExpos2 = MarketExpos2[_n-1] + (year != year[_n-1])*(MarketExpos2) if firmid == firmid[_n-1]
*But don't count experience gained THIS year
replace MarketExpos2 = MarketExpos2 - gainedthisyear
drop firstyear years_exposed counteachcountryonce gainedthisyear
*
drop if newobs == 1
drop newobs
*
****************************************************************************






********* *********		LAG VARIABLES	*********	*********	
* Create lagged variables and replace ONLY those that need to be lagged with their lagged value.
* 
egen firmyear=tag(firmid year)
keep if firmyear==1
*
encode firmid, gen(firmcode)
by firmid: gen number=_n
*
xtset firmcode number
*
foreach var in MarketExper1 MarketExper2 MarketExpos1 MarketExpos2 {
gen L_`var'=L.`var'
replace L_`var'=0 if L_`var'==.
}
****************************************************************************
***Replacing the unlagged with lagged

replace MarketExper1=L_MarketExper1

replace MarketExper2=L_MarketExper2



********* *********		CREATE FILE WITH EXPERIENCE VARIABLES 	*********	*********	
*
keep firmid year MarketExper1 MarketExper2 MarketExpos1 MarketExpos2 
 *L_MarketExper1 L_MarketExper2 L_MarketExpos1 L_MarketExpos2
save "ExperVars1.dta"
*
****************************************************************************



