*** This do file creates FIT home experience variables: FITexperHome, FITexposHome,   
*** AdverseExpHome, AdverseExposHome, PositiveExpHome, PositiveExposHome


capture erase "ExperVars2.dta" 	// delete the experience variables data if it exists


********* *********		POLICY EXPERIENCE 	*********	*********	



*** FITexperHome: 1 if the firm has been exposed to a FIT scheme in the home country.
*
*gen FITexperHome = hm_fits*FirmFromSolar
*
****************************************************************************



*** FITexposHome: number of years the company has been exposed to a FIT scheme in the home country
gen hm_rufitage_alt=hm_rufitage+1
gen firmage_alt=firmage+1
*
****If we take into account Firms from solar industry
*gen FITexposHome = min(hm_rufitage_alt,firmage_alt)*FirmFromSolar

***Removing the solar industry
gen FITexposHome = min(hm_rufitage_alt,firmage_alt)
**
replace FITexposHome=. if hm_rufitage==. // replace if we don't know the FIT age 

drop hm_rufitage_alt firmage_alt
*
****************************************************************************
*** FITexperHome: 1 if the firm has been exposed to a FIT scheme in the home country.
*
gen FITexperHome = 1 if FITexposHome>0



********* *********		ADVERSE EXPERIENCE 	*********	*********	




*** AdverseExpHome: 1 if the firm has recent adverse experience with a FIT scheme in its home country (repeal or reduction of at least 20% in the last year).
*
*gen AdverseExpHome = hm_rufitnegch20*FirmFromSolar
gen AdverseExpHome = hm_rufitnegch20
*
replace AdverseExpHome=1 if AdverseExpHome>0 & AdverseExpHome!=. 	// make it a dummy if it was exposed more than once
*
****************************************************************************




*** AdverseExposHome: the number of years the firm has been exposed to a FIT without significant changes in the home country (reverse coded)
*
*gen AdverseExposHome = -1*min(hm_rufitage,hm_ruyslfitch20)*FirmFromSolar
gen AdverseExposHome = -1*min(hm_rufitage,hm_ruyslfitch20)
*
replace AdverseExposHome=. if hm_rufitage==. 	// replace if we don't know the FIT age 

****AdverseExposHome1:  number of years the firm has been exposed to negative change, adding 1 to the previous observation if the firm was exposed in that year
sort firmid year
g AdverseExposHome1 = 0 if hm_rufitnegch20 > 0 & !missing(hm_rufitnegch20) & year >= foundingyear
replace AdverseExposHome1 = AdverseExposHome1[_n-1] + ((year != year[_n-1]) & (hm_rufitnegch20[_n-1] > 0)) if _n > 1 & firmid == firmid[_n-1] & AdverseExposHome1[_n-1] != .
replace AdverseExposHome1 = 0 if missing(AdverseExposHome1) & year >= foundingyear


****************************************************************************

****AdverseExposHomeAlt:the number of years the firm has been exposed to a FIT without significant negative changes in the home country (reverse coded) Alternative version of AdverseExposHome that does not rely on hm_ruyslfitch20**
by firmid, sort: egen firstyr = min(foundingyear)
replace firstyr = (hm_rufitnegch20==0)*firstyr[_n-1]+(hm_rufitnegch20>0)*(year) if firmid == firmid[_n-1]
gen AdverseExposHomeAlt = max(year - firstyr,0)*-1
replace AdverseExposHomeAlt=. if hm_rufitnegch20==.
drop firstyr 



***AdverseExposHomeUncert: the number of years the firm has been exposed to a FIT without significant changes in the home country (reverse coded) taking into account firmage

by firmid, sort: egen firstyr = min(foundingyear)
replace firstyr = (hm_ruyslfitch20>0)*firstyr[_n-1]+(hm_ruyslfitch20==0)*(year) if firmid == firmid[_n-1]
gen AdverseExposHomeUncert = max(year - firstyr,0)*-1
replace AdverseExposHomeUncert=. if hm_ruyslfitch20==.
drop firstyr

********* *********		POSITIVE EXPERIENCE 	*********	*********	


* NOTE: Use the same code as for adverse experience once the issues there have been resolved
* to create the following variables 



*** PositiveExpHome: 1 if the firm has recent Positive experience with a FIT scheme in its home country (increase of at least 20% in the last year).
*
gen PositiveExpHome = hm_rufitposch20*FirmFromSolar
*
replace PositiveExpHome=1 if PositiveExpHome>0 & PositiveExpHome!=. 
*
****************************************************************************






*** PositiveExposHome: the number of years the firm has been exposed to a FIT without significant changes in the host country (reverse coded), as accumulated across all host countries the firm has invested in.
*
*gen PositiveExposHome = .
 
*
****************************************************************************
*************ROBUSTNESS TEST VARIABLES*******
***
****AdversePast5Yr: takes value of 1 if the firm experienced adverse experience in the past 5 years***
****find out if there was negative change THIS year

by firmid year, sort: egen negthisyr = max(hm_rufitnegch20)
g yearwithchange = year*(negthisyr > 0 & !missing(negthisyr))

*Find out how long it's been since the last negative change
replace yearwithchange = (negthisyr[_n-1] == 0 | year == year[_n-1])*(yearwithchange[_n-1]) + (negthisyr[_n-1] == 1 & year != year[_n-1])*(year[_n-1]) if firmid == firmid[_n-1]
replace yearwithchange = 0 if negthisyr == 1 & (firmid[_n-1] != firmid)

*If it's been 5 yrs or less, this is a 1; etc.
gen AdversePast5Yr = inrange(year - yearwithchange,1,5) & !missing(yearwithchange)

****AdversePast3Yr: takes value of 1 if the firm experienced adverse experience in the past 3 years***

gen AdversePast3Yr = inrange(year - yearwithchange,1,3) & !missing(yearwithchange)

****AdversePast1Yr: takes value of 1 if the firm experienced adverse experience in the past year***

gen AdversePast1Yr = inrange(year - yearwithchange,1,1) & !missing(yearwithchange)

drop negthisyr yearwithchange



********* *********		LAG VARIABLES	*********	*********	
* Create lagged variables and replace ONLY those that need to be lagged with their lagged value.
* 
egen firmyear=tag(firmid year)
keep if firmyear==1
*
encode firmid, gen(firmcode)
by firmid: gen number=_n
*
xtset firmcode number
*
foreach var in FITexperHome  ///
 FITexposHome AdverseExpHome  ///
 AdverseExposHome  ///
 PositiveExpHome ///
 AdverseExposHomeAlt ///
 AdverseExposHomeUncert {
gen L_`var'=L.`var'
replace L_`var'=0 if L_`var'==.
}
****************************************************************************

***Replacing the unlagged with lagged values***
replace FITexperHome=L_FITexperHome
replace FITexposHome=L_FITexposHome
replace AdverseExpHome=L_AdverseExpHome
replace PositiveExpHome=L_PositiveExpHome
replace AdverseExposHomeUncert=L_AdverseExposHomeUncert


********* *********		CREATE FILE WITH EXPERIENCE VARIABLES 	*********	*********	
*
keep firmid year FITexperHome FITexposHome AdverseExpHome AdverseExposHome AdverseExposHome1 AdverseExposHomeAlt AdverseExposHomeUncert PositiveExpHome AdversePast5Yr AdversePast3Yr AdversePast1Yr
 **L_FITexperHome L_FITexposHome L_AdverseExpHome L_AdverseExposHome  ///
 *L_PositiveExpHome  
*
*
save "ExperVars2.dta"
*
****************************************************************************


