*** This do file creates FIT foreign experience variables: FITexperForeign, AdverseExpForeign,
*** AdverseExposForeign, PositiveExpForeign, PositiveExposForeign 


capture erase "ExperVars3.dta" 	// delete the experience variables data if it exists


*** FITexperForeign: number of foreign countries the firm has invested in that had a FIT for solar power at the time of investment.
*
*Get first year invested in that country
by firmid ccode2, sort: egen firstyr = min(year)
*and only count each country once, if invested multiple times the same year
by firmid ccode2 year, sort: gen n = _n
*Count the number of new FITS investments
gen new_fits = firstyr == year & n == 1 & hs_fits == 1
*count up all the new ones for that year
egen FITexperForeign = sum(new_fits), by(firmid year)
*then add in previous years
sort firmid year
replace FITexperForeign = FITexperForeign[_n-1] + (year != year[_n-1])*FITexperForeign if firmid == firmid[_n-1]
drop firstyr n new_fits
*
*** *************************************************************************

*** FITexposForeign: number of years the company has been exposed to a FIT across all its foreign solar investments
*
by firmid year ccode2, sort: gen counteachcountryonce = (_n == 1)*(hs_fits == 1)*(firminhost==1)
*count the number of FITS exposed to THAT year
by firmid year, sort: egen FITexposForeign = sum(counteachcountryonce)
*now, add in the FIT exposure from previous years
sort firmid year
replace FITexposForeign = FITexposForeign[_n-1] + (year != year[_n-1])*FITexposForeign if firmid == firmid[_n-1]

drop counteachcountryonce
*
****************************************************************************



*** AdverseExpForeign: number of foreign countries the firm has invested in and where it faced recent adverse experience with a FIT scheme (repeal or reduction of at least 20% in the last year).
gen droplastyear = hs_rufitnegch20 > 0 if !missing(hs_rufitnegch20)
by firmid year ccode2, sort: gen counteachcountryonce = (_n == 1)*droplastyear
*count up the number of adverse experiences THIS year
by firmid year, sort: egen AdverseExpForeign = sum(counteachcountryonce)
*keep a backup 
gen AdverseExpForeignbk = AdverseExpForeign
*then add in the previous years
sort firmid year
replace AdverseExpForeign = AdverseExpForeign[_n-1] + (year != year[_n-1])*AdverseExpForeign if firmid == firmid[_n-1]
*But don't count THIS year, just the lagged stuff
replace AdverseExpForeign = AdverseExpForeign - AdverseExpForeignbk
drop droplastyear counteachcountryonce AdverseExpForeignbk
*egen AdverseExpForeign=sum(hs_rufitnegch20), by(firmid year)

*
****************************************************************************
*** AdverseExposForeign: the number of years the firm has been exposed to a FIT without significant negative changes in the host country (reverse coded), as accumulated across all host countries the firm has invested in.
*
*count number of years firm has been there
by firmid ccode2, sort: egen firstyr = min(year)
sort firmid ccode2 year
replace firstyr = (hs_rufitnegch20==0)*firstyr[_n-1]+(hs_rufitnegch20>0)*(year+1) if firmid == firmid[_n-1] & ccode2 == ccode2[_n-1]
g yearsthere = year - firstyr + 1
by firmid year ccode2, sort: gen counteachcountryonce = (_n == 1)*-1*yearsthere
by firmid year, sort: egen AdverseExposForeign = sum(counteachcountryonce)
drop counteachcountryonce firstyr yearsthere

****AdverseExposForeign1: number of years the firm has been exposed to negative changes in FITs across foreign countries; adding 1 to each year when the change occurred***
sort firmid host year
g AdverseExposForeign1 = 0 if hs_rufitnegch20 > 0 & !missing(hs_rufitnegch20) & year >= foundingyear
replace AdverseExposForeign1 = AdverseExposForeign1[_n-1] + ((year != year[_n-1]) & (hs_rufitnegch20[_n-1] > 0)) if _n > 1 & firmid == firmid[_n-1] & host == host[_n-1] & AdverseExposForeign1[_n-1] != .
replace AdverseExposForeign1 = 0 if missing(AdverseExposForeign1) & year >= foundingyear
by firmid year, sort: egen temp = sum(AdverseExposForeign1)
replace AdverseExposForeign1 = temp
drop temp


**** AdverseExposForeignAlt : the number of years (without initial year of exposure) the firm has been exposed to a FIT without significant negative changes in the host country (reverse coded), as accumulated across all host countries the firm has invested in.
****Not counting the initial year of starting***
by firmid ccode2, sort: egen firstyr = min(year)
sort firmid ccode2 year
replace firstyr = (hs_rufitnegch20==0)*firstyr[_n-1]+(hs_rufitnegch20>0)*(year+1) if firmid == firmid[_n-1] & ccode2 == ccode2[_n-1]
g yearsthere = max(year - firstyr,0)
by firmid year ccode2, sort: gen counteachcountryonce = (_n == 1)*-1*yearsthere
by firmid year, sort: egen AdverseExposForeignAlt = sum(counteachcountryonce)
drop counteachcountryonce firstyr yearsthere
****************************************************************************
******AdverseExposForeignAver: average of adverse exposure in the foriegn country and number of host countries firm is present in that have FITs

gen AdverseExposForeignAver= AdverseExposForeign/ FITexperForeign
replace AdverseExposForeignAver=0 if AdverseExposForeignAver==.

*** AdverseExposDummy: equal to 1 if hs_rufitnegch20 is nonzero for any country in that firm/year
by firmid year, sort: egen AdverseExposDummy = max(hs_rufitnegch20)
replace AdverseExposDummy = min(AdverseExposDummy,1)
replace AdverseExposDummy = AdverseExposDummy[_n-1] if AdverseExposDummy == 0 & firmid == firmid[_n-1]

****AdverseExposForeignUncert1: the number of years the firm has been exposed to a FIT without significant policy changes in the host country (reverse coded), as accumulated across all host countries the firm has invested in.
by firmid ccode2, sort: egen firstyr = min(year)
sort firmid ccode2 year
replace firstyr = (hs_ruyslfitch20>0)*firstyr[_n-1]+(hs_ruyslfitch20==0)*(year+1) if firmid == firmid[_n-1] & ccode2 == ccode2[_n-1]
g yearsthere = year - firstyr + 1
by firmid year ccode2, sort: gen counteachcountryonce = (_n == 1)*-1*yearsthere
by firmid year, sort: egen AdverseExposForeignUncert1 = sum(counteachcountryonce)
drop counteachcountryonce firstyr yearsthere

********AdverseExposForeignUncert2: the number of years the firm has been exposed to a FIT without significant policy changes in the host country (reverse coded), as accumulated across all host countries the firm has invested in.
***Counting change in one country as 0 in all the countries in that year
by firmid ccode2, sort: egen firstyr = min(year)
by firmid year, sort: egen hs_ruyslfitch20_min = min(hs_ruyslfitch20)
sort firmid ccode2 year
replace firstyr = (hs_ruyslfitch20>0)*firstyr[_n-1] +(hs_ruyslfitch20==0)*(year) if firmid == firmid[_n-1] & ccode2 == ccode2[_n-1]
g yearsthere = min(year - firstyr,hs_ruyslfitch20_min)
by firmid year ccode2, sort: gen counteachcountryonce = (_n == 1)*-1*yearsthere
by firmid year, sort: egen AdverseExposForeignUncert2 = sum(counteachcountryonce)
drop counteachcountryonce firstyr yearsthere hs_ruyslfitch20_min

*
****************************************************************************



*** PositiveExpForeign: number of foreign countries the firm has invested in and where it faced recent Positive experience with a FIT scheme (repeal or reduction of at least 20% in the last year).
*
gen droplastyear = hs_rufitposch20 > 0 if !missing(hs_rufitposch20)
by firmid year ccode2, sort: gen counteachcountryonce = (_n == 1)*droplastyear
*count up the number of adverse experiences THIS year
by firmid year, sort: egen PositiveExpForeign = sum(counteachcountryonce)
*keep a backup 
gen PositiveExpForeignbk = PositiveExpForeign
*then add in the previous years
sort firmid year
replace PositiveExpForeign = PositiveExpForeign[_n-1] + (year != year[_n-1])*PositiveExpForeign if firmid == firmid[_n-1]
*But don't count THIS year, just the lagged stuff
replace PositiveExpForeign = PositiveExpForeign - PositiveExpForeignbk
drop droplastyear counteachcountryonce PositiveExpForeignbk

*
****************************************************************************
*** PositiveExposForeign: the number of years the firm has been exposed to a FIT without significant changes in the host country (reverse coded), as accumulated across all host countries the firm has invested in.


****Nina: HERE we need to substitute hs_rufitposch20 with positive equivalent of hs_ruyslfitch20 for the code to work***


*by firmid ccode2, sort: egen firstyr = min(year)
*gen yearsthere = year - firstyr + 1
*by firmid year ccode2, sort: gen counteachcountryonce = (_n == 1)*-1*min(yearsthere,hs_rufitposch20)
*by firmid year, sort: egen PositiveExposForeign = sum(counteachcountryonce)
*drop counteachcountryonce firstyr yearsthere
 
*
****PositiveExposDummy: equal to 1 if hs_rufitposch20 is nonzero for any country in that firm/year

by firmid year, sort: egen PositiveExposDummy = max(hs_rufitposch20)
replace PositiveExposDummy = min(PositiveExposDummy,1)
replace PositiveExposDummy = PositiveExposDummy[_n-1] if PositiveExposDummy == 0 & firmid == firmid[_n-1]


****ROBUSTNESS TEST VARIABLES*****
***********************************************************************************************************************************

*Stick out years with a negaive change
by firmid year, sort: egen negthisyr = max(hs_rufitnegch20)
replace negthisyr = min(1,negthisyr)
g yearwithchange = year*(negthisyr > 0 & !missing(negthisyr))

replace yearwithchange = (negthisyr[_n-1] == 0 | year == year[_n-1])*(yearwithchange[_n-1]) + (negthisyr[_n-1] == 1 & year != year[_n-1])*(year[_n-1]) if firmid == firmid[_n-1] 
replace yearwithchange = 0 if negthisyr == 1 & (firmid[_n-1] != firmid)


***AdverseForeignPast5Yr: takes the value of 1 if the firm has been exposed to negative change in the past 5 years in Any country
*If it's been 5 yrs or less, this is a 1; etc.
g AdverseForeignPast5Yr = inrange(year - yearwithchange,1,5) & !missing(yearwithchange)

***AdverseForeignPast3Yr: takes the value of 1 if the firm has been exposed to negative change in the past 3 years in Any country
g AdverseForeignPast3Yr = inrange(year - yearwithchange,1,3) & !missing(yearwithchange)

***AdverseForeignPast1Yr: takes the value of 1 if the firm has been exposed to negative change in the past 1 years in Any country
g AdverseForeignPast1Yr = inrange(year - yearwithchange,1,1) & !missing(yearwithchange)

drop negthisyr yearwithchange



****************************************************************************


********* *********		LAG VARIABLES	*********	*********	
* Create lagged variables and replace ONLY those that need to be lagged with their lagged value.
* 
egen firmyear=tag(firmid year)
keep if firmyear==1
*
encode firmid, gen(firmcode)
by firmid: gen number=_n
*
xtset firmcode number
*
foreach var in FITexperForeign FITexposForeign AdverseExpForeign AdverseExposForeign AdverseExposForeignAver AdverseExposForeignAlt AdverseExposDummy PositiveExpForeign PositiveExposDummy   {
gen L_`var'=L.`var'
replace L_`var'=0 if L_`var'==.
}
****************************************************************************
***Replacing unlagged with lagged****
replace FITexperForeign=L_FITexperForeign
replace FITexposForeign=L_FITexposForeign
replace AdverseExposForeign=L_AdverseExposForeign
replace AdverseExposForeignAver=L_AdverseExposForeignAver
replace AdverseExposDummy=L_AdverseExposDummy
replace PositiveExposDummy=L_PositiveExposDummy
 

********* *********		CREATE FILE WITH EXPERIENCE VARIABLES 	*********	*********	
*
keep firmid year FITexperForeign FITexposForeign AdverseExpForeign AdverseExposForeign AdverseExposForeign1 AdverseExposForeignAver AdverseExposForeignAlt AdverseExposDummy PositiveExpForeign PositiveExposDummy AdverseExposForeignUncert1 AdverseExposForeignUncert2 AdverseForeignPast5Yr AdverseForeignPast3Yr AdverseForeignPast1Yr  
* L_FITexperForeign L_FITexposForeign L_AdverseExpForeign L_AdverseExposForeign L_AdverseExposForeignAver L_AdverseExposForeignAlt L_AdverseExposDummy L_PositiveExpForeign L_PositiveExposDummy  
*
save "ExperVars3.dta"
*
****************************************************************************
