

*****************************************************************
******************Main models************************************
*****************************************************************


corr invchoice L_hs_fitprice ///
	   FITexposAll ///
	   MarketExpos2 ///
	   AdverseExposAll1 ///
	   agy_ngfijt L_fdi_netin_gdpperc  ///
	   geodistance  diffcap ///
	   uncertainty2_1 L_investfreed  ///
	   pigs easteu hs_highcorp hs_highlib ///
	   L_hs_demgrowth L_hs_solrad L_hs_prod L_hs_gdpch ///
	   L_hs_envvalues1 L_hs_regulother ///
	   , means
	   
	   

* Define the set of control variables 
global controlVars  agy_ngfijt L_fdi_netin_gdpperc  ///
			geodistance  diffcap ///
			uncertainty2_1 L_investfreed  ///
			pigs easteu hs_highcorp hs_highlib ///
			L_hs_demgrowth L_hs_solrad L_hs_prod L_hs_gdpch ///
			L_hs_envvalues1 L_hs_regulother 
	   
clogit invchoice $controlVars ///
   L_hs_fitprice ///
   , group(invid)	   

gen samplefinal=e(sample)
	   
* Test only control variables

clogit invchoice $controlVars if samplefinal==1 ///
   , group(invid)	   

outreg2 using Main.xls, ctitle(C) label e(r2_p ) se bdec(3) stats(coef se pval) alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) parenthesis(se) bracket(pval) append



* Test main effect and control variables (H1)

clogit invchoice $controlVars ///
   L_hs_fitprice ///
   , group(invid)	   
	  
outreg2 using Main.xls, ctitle(H1) label e(r2_p ) se bdec(3) stats(coef se pval) alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) parenthesis(se) bracket(pval) append

	   

* Test policy experience (H2)

clogit invchoice $controlVars ///
   c.L_hs_fitprice##c.FITexposAll ///
   , group(invid)	   
	  

outreg2 using Main.xls, ctitle(H2) label e(r2_p ) se bdec(3) stats(coef se pval) alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) parenthesis(se) bracket(pval) append


* Market experience (H3)

clogit invchoice $controlVars ///
   c.L_hs_fitprice##c.MarketExpos2 ///
   , group(invid)	   
	  

outreg2 using Main.xls, ctitle(H3) label e(r2_p ) se bdec(3) stats(coef se pval) alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) parenthesis(se) bracket(pval) append



gen a=L_hs_fitprice*FITexposAll
gen b=L_hs_fitprice*MarketExpos2

clogit invchoice $controlVars ///
   L_hs_fitprice a ///
   , group(invid)	   

estimates store nonmarket

clogit invchoice $controlVars ///
   L_hs_fitprice b ///
   , group(invid)	   

estimates store market

   
suest nonmarket market

testnl [nonmarket_invchoice]a = [market_invchoice]b



* Adverse experience (H4)

clogit invchoice $controlVars ///
   c.L_hs_fitprice##c.AdverseExposAll1 ///
   , group(invid)	   
	  
outreg2 using Main.xls, ctitle(H4) label e(r2_p ) se bdec(3) stats(coef se pval) alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) parenthesis(se) bracket(pval) append



* All

clogit invchoice $controlVars ///
   c.L_hs_fitprice##c.FITexposAll c.L_hs_fitprice##c.MarketExpos2 c.L_hs_fitprice##c.AdverseExposAll1 ///
   , group(invid)	   
	  
outreg2 using Main.xls, ctitle(Full) label e(r2_p ) se bdec(3) stats(coef se pval) alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) parenthesis(se) bracket(pval) append



*****************************************************************
*********************Robustness Tables***************************
*****************************************************************



clogit invchoice $controlVars ///
   c.L_hs_fitprice##c.FITexposAll c.L_hs_fitprice##c.MarketExpos2 c.L_hs_fitprice##c.AdverseExposAll1 ///
   if invouteu==0, group(invid)	   
	  
outreg2 using Robustness.xls, ctitle(Only EU) label e(r2_p ) se bdec(3) stats(coef se pval) alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) parenthesis(se) bracket(pval) append




clogit invchoice $controlVars ///
   c.L_hs_fitprice##c.FITexposAll c.L_hs_fitprice##c.MarketExpos2 c.L_hs_fitprice##c.AdverseExposAll1 ///
   if home!="Germany" , group(invid)	   
	  
outreg2 using Robustness.xls, ctitle(No Germany) label e(r2_p ) se bdec(3) stats(coef se pval) alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) parenthesis(se) bracket(pval) append



clogit invchoice $controlVars ///
   c.L_hs_fitprice##c.FITexposAll c.L_hs_fitprice##c.MarketExpos2 c.L_hs_fitprice##c.AdverseExposAll1 ///
   Invested , group(invid)	   
	  
outreg2 using Robustness.xls, ctitle(Prior Investment) label e(r2_p ) se bdec(3) stats(coef se pval) alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) parenthesis(se) bracket(pval) append




clogit invchoice $controlVars ///
   c.L_hs_fitprice##c.FITexposAll c.L_hs_fitprice##c.MarketExpos2 c.L_hs_fitprice##c.AdverseExposAll1 ///
   hs_runumnegch , group(invid)	   
	  
outreg2 using Robustness.xls, ctitle(Policy Uncertainty Short) label e(r2_p ) se bdec(3) stats(coef se pval) alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) parenthesis(se) bracket(pval) append




clogit invchoice $controlVars ///
   c.L_hs_fitprice##c.FITexposAll c.L_hs_fitprice##c.MarketExpos2 c.L_hs_fitprice##c.AdverseExposAll1 ///
   hs_runumnegch5 , group(invid)	   
	  
outreg2 using Robustness.xls, ctitle(Policy Uncertainty Long) label e(r2_p ) se bdec(3) stats(coef se pval) alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) parenthesis(se) bracket(pval) append




clogit invchoice $controlVars ///
   c.L_hs_fitprice##c.FITexposAll c.L_hs_fitprice##c.MarketExpos2 c.L_hs_fitprice##c.AdverseExposAll1 ///
   if FirmFromRE==0, group(invid)	   
	  
outreg2 using Robustness.xls, ctitle(Not Renewables) label e(r2_p ) se bdec(3) stats(coef se pval) alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) parenthesis(se) bracket(pval) append



clogit invchoice $controlVars ///
   c.L_hs_fitprice##c.FITexposAll c.L_hs_fitprice##c.MarketExpos2 c.L_hs_fitprice##c.AdverseExposAll1 ///
   if FirmFromRE==1, group(invid)	   
	  
outreg2 using Robustness.xls, ctitle(Renewables) label e(r2_p ) se bdec(3) stats(coef se pval) alpha(0.001, 0.01, 0.05, 0.1) symbol(***, **, *, +) parenthesis(se) bracket(pval) append


